//----------------------------------------------------------------------------
//  Project WmPlayer
//  OWLNext community
//  (C) 2007 OWLNext community
//
//  SUBSYSTEM:    WmPlayer Application
//  FILE:         wmplyrdc.cpp
//  AUTHOR:       Sebastian Ledesma
//
//  OVERVIEW
//  ~~~~~~~~
//  Source file for implementation of TWmPlayerDlgClient (TDialog).
//
//----------------------------------------------------------------------------

#include <owl/pch.h>
#include <owl/opensave.h>

#include "wmplyrap.h"
#include "wmplyrdc.h"


//
// Build a response table for all messages/commands handled by the application.
//
DEFINE_RESPONSE_TABLE1(TWmPlayerDlgClient, TOleDialog)
//{{TWmPlayerDlgClientRSP_TBL_BEGIN}}
  EV_WM_SIZE,
  EV_BN_CLICKED(IDC_OPEN, OnOpen),
  EV_BN_CLICKED(IDC_PLAY, OnPlay),
  EV_BN_CLICKED(IDC_STOP, OnStop),
//{{TWmPlayerDlgClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//{{TWmPlayerDlgClient Implementation}}


//--------------------------------------------------------
// TWmPlayerDlgClient
// ~~~~~~~~~~
// Construction/Destruction handling.
//
//static TWmPlayerDlgClientXfer TWmPlayerDlgClientData;

TWmPlayerDlgClient::TWmPlayerDlgClient(TWindow* parent, TResId resId, TModule* module)
:
  TOleDialog(parent, resId, module) {
//{{TWmPlayerDlgClientXFER_USE}}
  pBtn_Open = new TButton(this, IDC_OPEN);
  pBtn_Play = new TButton(this, IDC_PLAY);
  pBtn_Stop = new TButton(this, IDC_STOP);
  pBtn_Ok = new TButton(this, IDOK);

//  SetTransferBuffer(&TWmPlayerDlgClientData);
//{{TWmPlayerDlgClientXFER_USE_END}}

  // INSERT>> Your constructor code here.

  // Create TOcDocument object to hold OLE parts
  // and TOcView object to provide OLE services.
  // CreateOcView(0, false, 0);
  //Not needed, will be called in TOleWindow::Setup if not called here

	//SetBkgndColor(RGB(0x80, 0xA0, 0xe0)); //8f af cf
   Ocx=NULL;

}


TWmPlayerDlgClient::~TWmPlayerDlgClient() {
//  Destroy(); not needed, it will called by TOleDialog destructor

  // INSERT>> Your destructor code here.
}

void TWmPlayerDlgClient::SetupWindow() {
	TOleDialog::SetupWindow();

	// Note 1: the ProgID must be used as caption in the control
	// "MediaPlayer.MediaPlayer.1" for classic Media Player (msdxm.ocx)
	// "WMPlayer.OCX.7" for new Media Player (wmp.dll)

	GUID  guidMediaPlayer = CLSID_NULL;

#define USE_PROGID_TO_OBTAIN_GUID 1
#if USE_PROGID_TO_OBTAIN_GUID
	CLSIDFromProgID(TString("MediaPlayer.MediaPlayer.1"), &guidMediaPlayer); //classic Media player
	//CLSIDFromProgID(TString("WMPlayer.OCX.7"), &guidMediaPlayer); //for new Media Player

	if (guidMediaPlayer==CLSID_NULL)
		MessageBox("MediaPlayer not installed in this system","Error",MB_OK);
#else
	guidMediaPlayer=IID_IMediaPlayer2; //classic Media player GUID
   // guidMediaPlayer= {6BF52A52-394A-11D3-B153-00C04F79FAA6} //Media Player 7-9 GUID
#endif
	Ocx = GetOcControlOfOCX(guidMediaPlayer, IDC_MEDIAPLAYER);
	if (!Ocx) {
		MessageBox("Can't find to OCX control using GUID and control ID, switch to GUID only mode", "Warning", MB_OK);
		Ocx = GetOcControlOfOCX(guidMediaPlayer);
	}

	if (Ocx)
		Proxy.Bind(Ocx->GetCtlDispatch());
	else
		MessageBox("Can't bind to OCX control.\r\nMedia Player not correctly installed?", "Error", MB_OK);


   //Resize the main window (TOleFrame) to the dialog client
	TRect drect;
	TRect srect;
	GetWindowRect(drect);
	AdjustWindowRectEx(drect, Parent->GetStyle(), false, Parent->GetExStyle());
	Parent->SetWindowPos(0, drect, SWP_NOMOVE|SWP_NOZORDER|SWP_SHOWWINDOW);

	if (Ocx) { //We cannot use SetWindowPos on a OcControl
      Ocx->SetTop(14);	//use specific API
      Ocx->SetLeft(5);
	}

}


void TWmPlayerDlgClient::CleanupWindow() {
  // INSERT>> Your code here.
	/*
	if (Ocx) {
		//best place is to put in CanClose,
		//but requires closing the dialog with [ok]
		//since [cancel] wont call CanClose!
		Proxy.Stop();
		Proxy.Unbind();
		Ocx=NULL;
   }*/

  TOleDialog::CleanupWindow();
}


void TWmPlayerDlgClient::EvSize(uint sizeType, TSize& size) {
	TOleDialog::EvSize(sizeType, size);

	// INSERT>> Your code here.
	if (sizeType != SIZEICONIC ) {
	  	if (Ocx) {
  			//Ocx->SetWindowPos(0, 10, 10, size.cx-10, size.cy-40-10, SWP_NOZORDER | SWP_NOMOVE);
      	Ocx->SetWidth(size.cx-10);
	      Ocx->SetHeight(size.cy-40-10);
      }

		pBtn_Open->SetWindowPos(0, 10, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
		pBtn_Play->SetWindowPos(0, 100, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
		pBtn_Stop->SetWindowPos(0, 190, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
		pBtn_Ok->SetWindowPos(0, 280, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
	}
}

void TWmPlayerDlgClient::OnOpen(){
  // INSERT>> Your code here.
  char filename[MAX_PATH];
  TFileOpenDialog::TData FilenameData (OFN_FILEMUSTEXIST | OFN_PATHMUSTEXIST | OFN_NOCHANGEDIR,
	    "Media files (*.avi;*.mp?;*.wav)|*.avi;*.mp?;*.wav|AVI Files (*.avi)|*.avi|Wave Files (*.wav)|*.wav|MPEG Files (*.mp?)|*.mp?|",
   	  0, filename, 0, 0 /*4096*/);
  if (TFileOpenDialog(this, FilenameData).Execute() != IDOK)
			return;

  //TBSTR bstrFilename;     //defined in <ocf/oleutil.h>
  //TSysStr sysStrFilename; //defined in <winsys/string.h>

  //BSTR  bstrFilename=::SysAllocString(L"DEMO.MP3");

  wchar_t wFilename[MAX_PATH];
  MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, FilenameData.FileName, -1, wFilename, MAX_PATH);

  //TR  bstrFilename=::SysAllocString(FilenameData.FileName);
  BSTR  bstrFilename=::SysAllocString(wFilename);

  Proxy.Open(bstrFilename);

  ::SysFreeString(bstrFilename);
}


void TWmPlayerDlgClient::OnPlay() {
  // INSERT>> Your code here.
  Proxy.Play();
}


void TWmPlayerDlgClient::OnStop() {
  // INSERT>> Your code here.
  Proxy.Stop();
}


bool TWmPlayerDlgClient::CanClose() {
	if (Ocx) {
   	Proxy.Stop();
		Proxy.Unbind();
      Ocx=NULL;
   }

  bool result;
  result = TOleDialog::CanClose();
  // INSERT>> Your code here.

  return result;
}

